@@ -2,3 +2,5 @@ from .main import shift_lst, dictnamedtuple, easy_argparse
 from .pickles import dump_pickle, load_pickle
 from .unzip import unzip
 from .str_utils import color_str
+from .seeds import tf_set_seed
+from .logging_ import get_logger
